FixedModel
==========

.. currentmodule:: pykeen.models

.. autoclass:: FixedModel
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~FixedModel.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~FixedModel.collect_regularization_term
      ~FixedModel.score_h
      ~FixedModel.score_hrt
      ~FixedModel.score_r
      ~FixedModel.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: collect_regularization_term
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_r
   .. automethod:: score_t
